
XEP-0404: MIX-ANON
==================

.. module:: slixmpp.plugins.xep_0404

.. autoclass:: XEP_0404
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0404.stanza
    :members:
    :undoc-members:

